class botInfo:
    def __init__(self, data):
        self.json = data

        try: self.botId: int = data["id"]
        except (KeyError, TypeError): self.botId: int = -1

        try: self.prefix: str = data["prefix"]
        except (KeyError, TypeError): self.prefix: str = "Undefined"

        try: self.library: str = data["library"]
        except (KeyError, TypeError): self.library: str = "Undefined"

        try: self.description: str = data["description"]
        except (KeyError, TypeError): self.description: str = "Undefined Description"

        try: self.overview: str = data["overview"]
        except (KeyError, TypeError): self.overview: str = "Undefined Overview"

        try: self.discordInvite: str = data["discordInvite"]
        except (KeyError, TypeError): self.discordInvite: str = "Undefined Invite"

        try: self.boosted: bool = data["boosted"]
        except (KeyError, TypeError): self.boosted: bool = False

        try: self.promoted: bool = data["promoted"]
        except (KeyError, TypeError): self.promoted: bool = False

        try: self.vanity: str = data["vanity"]
        except (KeyError, TypeError): self.vanity: str = "Undefined Vanity"

        try: self.github: str = data["github"]
        except (KeyError, TypeError): self.github: str = "Undefined Github"

        try: self.donateUrl: str = data["donateUrl"]
        except (KeyError, TypeError): self.donateUrl: str = "Undefined DonateUrl"

        try: self.serverCount: int = data["serverCount"]
        except (KeyError, TypeError): self.serverCount: int = -1

        try: self.shardCount: int = data["shardCount"]
        except (KeyError, TypeError): self.shardCount: int = -1

        # Lists
        try: self.owners: str = data["owners"]
        except (KeyError, TypeError): self.owners: str = "Undefined List"

        try: self.voters: str = data["voters"]
        except (KeyError, TypeError): self.voters: str = "Undefined List"

        try: self.tags: str = data["tags"]
        except (KeyError, TypeError): self.tags: str = "Undefined List"

        # Made by https://wezacon.com - Team Wezacon


class NotFound(Exception):
    def __init__(*args, **kwargs):
        Exception.__init__(*args, **kwargs)

class LibraryUpdateAvailable(Exception):
    def __init__(*args, **kwargs):
        Exception.__init__(*args, **kwargs)

def CheckException(data):
    errorCode: str = data["error"]
    errorMessage: str = data["response"]

    if errorCode != "true": raise NotFound(errorMessage)
    else: raise Exception(errorMessage)


import ujson as json
import requests
from pymongo import MongoClient

from .lib.util import objects, exceptions


class Client(object):
    def __init__(self, mongoUri: str, siteUrl: str, debug: bool):
        self.mongoDb = mongoUri
        self.siteUri = siteUrl
        self.debugMode = debug
        mongoCli = MongoClient('MONGOURL')
        self.db = mongoCli["easyvanity"]
        if debug == True:
            print('Attempted connection to the database.')

    def createVanity(self, vanityLink: str, ownerId: str, callbackUrl: str):
        if self.mongoDb is None:
            return print('Error: No mongoUri defined...')
        else:
            url = {
                "vanityLink": str(vanityLink),
                "callback": str(callbackUrl),
                "ownerId": str(ownerId),
                "disabled": False
            }
            existing = self.db.urls.find_one({ "vanityLink": vanityLink })
            if existing is None:
                self.db.urls.insert_one(url)
                self.db.users.find_one({ "vanityLink": vanityLink })
                return f"Vanity created: {vanityLink}"
            else:
                return print('VanityLink already exists!')
        # headers = {
        #     "Authorization": apiKey
        # }
        # response = requests.get(f"{self.api}/public/bot/{botId}", headers=headers)
        # if response.status_code != 200: raise exceptions.CheckException(json.loads(response.text))
        # else: return objects.botInfo(json.loads(response.text)["response"])